summaryrefslogtreecommitdiff
path: root/src/cache.hpp
diff options
context:
space:
mode:
authorCedric Nugteren <web@cedricnugteren.nl>2017-09-23 17:50:44 +0200
committerCedric Nugteren <web@cedricnugteren.nl>2017-09-23 17:50:44 +0200
commit890281f3e8b9c0523e69500d0860aa7085e7fbe1 (patch)
tree935d86ce3b7aa08c8025e1cb55ec79af11572b70 /src/cache.hpp
parent0dd2ca9283285f4144e4b5b7b809c31d1a70e856 (diff)
Made database-caching no longer dependent on device name but on device/platform IDs
Diffstat (limited to 'src/cache.hpp')
-rw-r--r--src/cache.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/cache.hpp b/src/cache.hpp
index ed693ea3..f6a948b6 100644
--- a/src/cache.hpp
+++ b/src/cache.hpp
@@ -93,9 +93,9 @@ extern template Program ProgramCache::Get(const ProgramKeyRef &, bool *) const;
class Database;
// The key struct for the cache of database maps.
-// Order of fields: precision, device_name, kernel_name (smaller fields first)
-typedef std::tuple<Precision, std::string, std::string> DatabaseKey;
-typedef std::tuple<const Precision &, const std::string &, const std::string &> DatabaseKeyRef;
+// Order of fields: platform_id, device_id, precision, kernel_name (smaller fields first)
+typedef std::tuple<cl_platform_id, cl_device_id, Precision, std::string> DatabaseKey;
+typedef std::tuple<const cl_platform_id &, const cl_device_id &, const Precision &, const std::string &> DatabaseKeyRef;
typedef Cache<DatabaseKey, Database> DatabaseCache;